@@ -16,7 +16,7 @@ use DynaLoader();
 use Carp ();
 @ISA = qw(DynaLoader);
 
-$VERSION = '2.01_18';
+$VERSION = '2.01_20';
 
 bootstrap DBD::mSQL $VERSION;
 
@@ -59,7 +59,7 @@ sub _OdbcParse($$$) {
 	if ($val =~ /([^=]*)=(.*)/) {
 	    $var = $1;
 	    $val = $2;
-	    if ($var eq 'hostname') {
+	    if ($var eq 'hostname'  ||  $var eq 'host') {
 		$hash->{'host'} = $val;
 	    } elsif ($var eq 'db'  ||  $var eq 'dbname') {
 		$hash->{'database'} = $val;
@@ -307,6 +307,7 @@ Interface (DBI)
 
     $driver = "mysql";
     $dsn = "DBI:$driver:database=$database;host=$hostname;port=$port";
+    if ($compression) { $dsn .= ";mysql_compression=1"; }
 
     $dbh = DBI->connect($dsn, $user, $password);
 
@@ -376,6 +377,8 @@ of the I<Msql-Mysql-modules> package.
     $dsn = "DBI:mysql:database=$database;host=$hostname";
     $dsn = "DBI:mysql:database=$database;host=$hostname;port=$port";
 
+    if ($compression) { $dsn .= ";mysql_compression=1"; }
+
     $dbh = DBI->connect($dsn, $user, $password);
 
 A C<database> must always be specified.
@@ -389,6 +392,10 @@ you may explicitly state the port number to connect to in the C<hostname>
 argument, by concatenating the I<hostname> and I<port number> together
 separated by a colon ( C<:> ) character.
 
+As of MySQL 3.22.3, a new feature is supported: If your DSN contains
+the option "mysql_compression=1", then the communication between client
+and server will be compressed.
+
 =back
 
 =head2 Private MetaData Methods
@@ -672,12 +679,24 @@ I<DELETE> or I<UPDATE>.
 
 A reference to an array of table names, useful in a I<JOIN> result.
 
-=item type
+=item TYPE
+
+A reference to an array of column types. The engine's native column
+types are mapped to portable types like DBI::SQL_INTEGER() or
+DBI::SQL_VARCHAR(), as good as possible. Not all native types have
+a meaningfull equivalent, for example DBD::mSQL::IDX_TYPE() or
+DBD::mysql::FIELD_TYPE_INTERVAL are mapped to DBI::SQL_VARCHAR().
+If you need the native column types, use I<mysql_type> or I<msql_type>,
+respectively. See below.
+
+
+=item mysql_type
+
+A reference to an array of mSQL's native column types, for example
+DBD::mSQL::INT_TYPE() or DBD::mSQL::CHAR_TYPE().
+Use the I<TYPE> attribute, if you want portable types like
+DBI::SQL_INTEGER() or DBI::SQL_VARCHAR().
 
-A reference to an array of column types. It depends on the DBMS,
-which values are returned, even for identical types. mSQL will
-return types like &DBD::mSQL::INT_TYPE, &DBD::msql::TEXT_TYPE etc.,
-MySQL uses &DBD::mysql::FIELD_TYPE_SHORT, &DBD::mysql::FIELD_TYPE_STRING etc.
 
 =back
 
@@ -705,6 +724,12 @@ of table $table. See the docs of msqlListIndex for details.
 
 =head1 COMPATIBILITY ALERT
 
+The statement attribute I<TYPE> has changed its meaning, as of
+Msql-Mysql-modules 1.19_19. Formerly it used to be the an array
+of native engine's column types, but it is now an array of
+portable SQL column types. The old attribute is still available
+as I<mysql_type> or I<msql_type>, respectively.
+
 Certain attributes methods have been declared obsolete or deprecated,
 partially because there names are agains DBI's naming conventions,
 partially because they are just superfluous or obsoleted by other methods.
@@ -770,8 +795,6 @@ deprecated, use
 
 =item TABLE
 
-=item TYPE
-
 All these statement handle attributes are obsolete. They can be simply
 replaced by just downcasing the attribute names. You should expect them
 to be deprecated as of Msql-Mysql-modules 1.1821. (Whenever that will
