@@ -7,7 +7,7 @@ package Mysql::Statement;
 use strict;
 use vars qw($OPTIMIZE $VERSION $AUTOLOAD);
 
-$VERSION = '1.19_18';
+$VERSION = '1.19_20';
 
 $OPTIMIZE = 0; # controls, which optimization we default to
 
@@ -55,7 +55,7 @@ sub arrAttr ($$) {
 }
 sub table ($) { shift->arrAttr('table') }
 sub name ($) { shift->arrAttr('NAME') }
-sub type ($) { shift->arrAttr('type') }
+sub type ($) { shift->arrAttr('mysql_type') }
 sub isnotnull ($) { shift->arrAttr('is_not_null') }
 sub isprikey ($) { shift->arrAttr('is_pri_key') }
 sub isnum ($) { shift->arrAttr('is_num') }
